.. argparse documentation master file, created by
   sphinx-quickstart on Sun Mar 27 01:27:16 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to argparse's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 2

   argparse
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

